## 0.4.0

* NOT Backwards Compatible: The verbosity_flag is now required for 'set_logging_verbosity' function.

## 0.3.0

* NOT Backwards Compatible: Remove optional verbosity flag from 'init_console_logging' function.
* Enable syslog logging.

## 0.2.1

* Documentation updates.

## 0.2.0

* Provide `add_verbosity_flag` function, as an alternate method to enable '-vv' in CLI tools.

## 0.1.0

* Enable pretty console logging for an entire package.
* Provide argparse 'parent parser' solution, enabling '-vv' in CLI tools.